@@ -1,7 +1,7 @@
 """
 Type annotations for elb service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html)
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -24,7 +24,7 @@ from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_elb.type_defs import (
+from .type_defs import (
     DescribeAccessPointsOutputTypeDef,
     DescribeAccountLimitsOutputTypeDef,
     PaginatorConfigTypeDef,
@@ -35,27 +35,27 @@ __all__ = ("DescribeAccountLimitsPaginator", "DescribeLoadBalancersPaginator")
 
 class DescribeAccountLimitsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeaccountlimitspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)[Show boto3-stubs documentation](./paginators.md#describeaccountlimitspaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeAccountLimitsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeaccountlimitspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describeaccountlimitspaginator)
         """
 
 
 class DescribeLoadBalancersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeloadbalancerspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)[Show boto3-stubs documentation](./paginators.md#describeloadbalancerspaginator)
     """
 
     def paginate(
         self, LoadBalancerNames: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeAccessPointsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeloadbalancerspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describeloadbalancerspaginator)
         """
